"use strict";
/*
Copyright 2019 Udacity, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// Primarily exists to implement the Cache API:
// https://developers.cloudflare.com/workers/reference/cache-api/
// Import the service-worker-mock types.
/// <reference types="@udacity/types-service-worker-mock" />
// Import the service-worker-mock global augmentations.
require("@udacity/types-service-worker-mock/global");
const service_worker_mock_1 = __importDefault(require("service-worker-mock"));
/**
 * Create a mock environment for a Cloudflare Worker with a mockable cache layer.
 */
function makeCloudflareWorkerEnv(envOptions) {
    const serviceWorkerEnv = service_worker_mock_1.default(envOptions);
    const cloudflareWorkerEnv = serviceWorkerEnv;
    cloudflareWorkerEnv.caches = {
        default: {
            put(_request, _response) {
                return new Promise((resolve, _reject) => {
                    resolve(undefined);
                });
            },
            match(_request, _options) {
                return new Promise((resolve, _reject) => {
                    resolve(undefined);
                });
            },
            delete(_request, _options) {
                return new Promise((resolve, _reject) => {
                    resolve(false);
                });
            },
        },
    };
    return cloudflareWorkerEnv;
}
exports.makeCloudflareWorkerEnv = makeCloudflareWorkerEnv;
/**
 * Create a mock KV for a Cloudflare Worker
 */
function makeCloudflareWorkerKVEnv(name) {
    const cloudflareWorkerKV = {
        get(_key, _type) {
            return Promise.resolve(undefined);
        },
        put(_key, _value) {
            return Promise.resolve(undefined);
        },
        delete(_key) {
            return Promise.resolve(undefined);
        },
        list(_prefix, _limit, _cursor) {
            return Promise.resolve({
                cursor: '1234567890',
                keys: [{ name: 'foo', expiration: 1234 }],
                list_complete: true,
            });
        },
    };
    const cloudflareWorkerKVEnv = {
        [name]: cloudflareWorkerKV,
    };
    return cloudflareWorkerKVEnv;
}
exports.makeCloudflareWorkerKVEnv = makeCloudflareWorkerKVEnv;
/**
 * Create a mock Request for a Cloudflare Worker
 *
 * A CloudflareRequestAttributes object can be created manually, but it requires
 * the developer to specify every field. This helper function allows the
 * developer to specify only fields required by tests.
 */
function makeCloudflareWorkerRequest(input, init) {
    if (init == null) {
        return new Request(input);
    }
    const attr = init.cf;
    const tlsAttr = attr.tlsClientAuth || {};
    const cf = {
        asn: attr.asn || '395747',
        city: attr.city || 'Austin',
        colo: attr.colo || 'AUS',
        continent: attr.continent || 'NA',
        country: attr.country || 'US',
        exclusive: attr.exclusive || '0',
        group: attr.exclusive || '0',
        'group-weight': attr['group-weight'] || '0',
        httpProtocol: attr.httpProtocol || 'HTTP/2',
        latitude: attr.latitude || 30.2713,
        longitude: attr.longitude || -97.7426,
        postalCode: attr.postalCode || '78701',
        region: attr.region || 'Texas',
        regionCode: attr.regionCode || 'TX',
        requestPriority: attr.requestPriority || 'weight=192;exclusive=0;group=3;group-weight=127',
        timezone: attr.timezone || 'America/Chicago',
        tlsCipher: attr.tlsCipher || 'AEAD-AES128-GCM-SHA256',
        tlsClientAuth: {
            certFingerprintSHA1: tlsAttr.certFingerprintSHA1 || '',
            certIssuerDN: tlsAttr.certIssuerDN || '',
            certIssuerDNLegacy: tlsAttr.certIssuerDNLegacy || '',
            certIssuerDNRFC2253: tlsAttr.certIssuerDNRFC2253 || '',
            certNotAfter: tlsAttr.certNotAfter || 'Dec 22 19:39:00 2018 GMT',
            certNotBefore: tlsAttr.certNotBefore || 'Dec 22 19:39:00 2018 GMT',
            certPresented: tlsAttr.certPresented || '1',
            certSerial: tlsAttr.certSerial || '',
            certSubjectDN: tlsAttr.certSubjectDN || '',
            certSubjectDNLegacy: tlsAttr.certSubjectDNLegacy || '',
            certVerified: tlsAttr.certVerified || 'SUCCESS',
        },
        tlsVersion: attr.weight || 'TLSv1.3',
        weight: attr.weight || '0',
    };
    const request = new Request(input, init);
    // Manually add CloudflareRequestAttributes since new Request() drops them.
    request.cf = cf;
    return request;
}
exports.makeCloudflareWorkerRequest = makeCloudflareWorkerRequest;
exports.default = makeCloudflareWorkerEnv;
